import React, { useEffect } from "react";
import './App.css';
import {
  Navigate,
  Route,
  Routes,
  BrowserRouter,
} from 'react-router-dom';
import { ThemeProvider } from "@material-ui/core/styles"
import { CssBaseline } from "@material-ui/core";
import { theme } from "./style/Theme";
import { IOCListView } from './views/IOC/IOCListView';
import { HomeAccessControl } from './views/home/HomeAccessControl';
import { GlobalAppBar } from './components/navigation/GlobalAppBar/GlobalAppBar';
import { IOCDetailsAccessControl } from './views/IOC/IOCDetailsAccessControl';
import { DeploymentDetailsAccessControl } from './views/deployments/DeploymentDetailsAccessControl';
import { APIProvider, UserProvider } from './api/SwaggerApi';
import { HostListView } from "./views/host/HostListView";
import { HostDetailsAccessControl } from "./views/host/HostDetailsAccessControl";
import { StatisticsView } from "./views/statistics/StatisticsView";
import { HelpView } from "./views/help/HelpView";
import { AboutView } from "./views/about/AboutView";
import { SnackbarProvider } from 'notistack';
import TokenRenew from './components/auth/TokenRenew';
import { NotificationProvider } from './components/common/notification/Notifications';
import NotFound from './components/navigation/NotFound';
import { applicationSubTitle } from './components/common/Helper';
import { AppErrorBoundary } from "./components/navigation/ErrorBoundary/ErrorBoundary";
import { LoginView } from "./views/login/LoginView";
import { LoginSuggester } from "./components/navigation/LoginSuggester/LoginSuggester";
import { JobLogAccessControl } from "./views/jobs/JobLogAccessControl";
import { RecordListView } from './views/records/RecordListView';

//setting up the application (TAB)title
function App() {
  useEffect(() => {
    document.title = "CE deploy & monitor" + applicationSubTitle();
  }, []);

  return (
    <AppErrorBoundary>
      <SnackbarProvider preventDuplicate maxSnack="5">
        <ThemeProvider theme={theme}>
          <CssBaseline />
          <BrowserRouter>
            <APIProvider >
              <UserProvider>
                <LoginSuggester>
                  <TokenRenew />
                  <NotificationProvider>
                    <GlobalAppBar>
                      <Routes>
                        <Route path="/" element={<Navigate to="/home" />} exact/>
                        <Route path="/home" element={<HomeAccessControl />} exact/>
                        <Route path="/records" element={<RecordListView />} exact/>
                        <Route path="/iocs/:id" element={<IOCDetailsAccessControl exact/>} />
                        <Route path="/iocs" element={<IOCListView />} exact/>
                        <Route path="/deployments/:id" element={<DeploymentDetailsAccessControl exact/>} />
                        <Route path="/jobs" element={<JobLogAccessControl />} exact/>
                        <Route path="/hosts/:id" element={<HostDetailsAccessControl />} exact/>
                        <Route path="/hosts" element={<HostListView />} exact/>
                        <Route path="/statistics" element={<StatisticsView />} exact/>
                        <Route path="/help" element={<HelpView />} exact/>
                        <Route path="/about" element={<AboutView />} exact/>
                        <Route path="/login" element={<LoginView />} exact/>
                        <Route path="*" element={<NotFound />} exact/>
                      </Routes>
                    </GlobalAppBar>
                  </NotificationProvider>
                </LoginSuggester>
              </UserProvider>
            </APIProvider>
          </BrowserRouter>
        </ThemeProvider>
      </SnackbarProvider>
    </AppErrorBoundary>
  );
}

export default App;
