import React from "react";
import {
  Container,
  Table,
  TableBody,
  TableCell,
  TableRow,
  Typography,
} from "@material-ui/core";

// const StyledTableRow = withStyles((theme) => ({
//   root: {
//     '&:nth-of-type(odd)': {
//       backgroundColor: theme.palette.action.hover,
//     },
//   },
// }))(TableRow);

/*
  KEY-VALUE table visualiser
  VALUE can be an object, or component
  If you want to style the while entry, use a records for the VALUE
  VALUE should consis of {shownValue:xxx, shownClass:yyy}
*/

export function KeyValueTable({ obj, variant = "overline" }) {

  /**
   * Trying to extract style class from the entry.
   * If there is no style class NULL value will be returned.
   * 
   * @param {*} value: The VALUE part of the entry 
   * @returns The style class name if it exists in the VALUE part.
   * If there is not style class NULL value will be returned
   */
  function extractStyle(value) {

    if (!value) {
      return null;
    }

    if (typeof (value) !== "object") {
      return null;
    }

    if (value.shownClass) {
      return value.shownClass;
    }

   return null;
  }

  /**
   * Returning the "formatted" KEY part of the entry for overline variant. 
   * If VALUE has style class the KEY part will use the same style.
   * 
   * @param {*} key: The KEY part of the entry 
   * @param {*} value: Then VALUE part of the entry that may contain Style class
   * @returns: The "formatted" KEY part for the table
   */
  function extractKey(key, value) {

    const externalStyle = extractStyle(value);

    if (externalStyle) {
      return <Typography variant="overline" className={externalStyle}>
        {key}
      </Typography>
    }

    return (<Typography variant="overline">
      {key}
    </Typography>)
  }

  /**
   * Returning the "formatted" VALUE part of the entry.
   * If the VALUE part contains style class it will use it.
   * 
   * @param {*} value: The VALUE part of the entry that may contain Style class
   * @returns: The "formatted" VALUE part for the table
   */
  function extractValue(value) {

    const externalStyle = extractStyle(value);

    if (externalStyle) {
      return <div className={externalStyle}>{value.shownValue}</div>
    }

    return typeof (value) !== "object" ?
      <Typography>
        {`${value}`}
      </Typography>
      : <div>{value}</div>
  }

  /**
   * Returning the "formatted" KEY part of the entry for table variant. 
   * If VALUE has style class the KEY part will use the same style.
   * 
   * @param {*} key: The KEY part of the entry 
   * @param {*} value: Then VALUE part of the entry that may contain Style class
   * @returns: The "formatted" KEY part for the table
   */
  function extractKeyForTable(key, value) {
    const externalStyle = extractStyle(value);

    if (externalStyle) {
      return <div className={externalStyle}>
        <strong>{key}</strong>
      </div>
    }

    return <strong>{key}</strong>;
  }

  return (
    <Container style={{ overflow: "auto" }}>
      <Table>
        <TableBody size="small">
          {Object.keys(obj).map((key) =>
            <TableRow key={key}>
              {
                (variant === "table") &&
                <TableCell >
                  {extractKeyForTable(key, obj[key])}
                </TableCell>
              }
              <TableCell>
                {
                  (variant === "overline") &&
                  extractKey(key, obj[key])
                }
                {
                  extractValue(obj[key])
                }
              </TableCell>
            </TableRow>
          )}
        </TableBody>
      </Table>
    </Container>
  );
}