import React from "react";
import { CustomTable } from '../common/table/CustomTable';

const recordsColumns = [
	{ id: 'name', label: 'Record', width: '15ch' },
	{ id: 'iocName', label: 'IOC name', width: '15ch' },
	{ id: 'hostName', label: 'Host', width: '15ch' },
];

const iocDetailsColumns = [
  { id: 'name', label: 'Record', width: '30ch' },
];

export function createRecordsRow(record) {
	return {
		name: record.name,
		iocName: record.iocName,
		hostName: record.hostName
	};
}

export function createIocDetailsRow(record) {
	return {
		name: record.name,
		iocName: record.iocName,
		hostName: record.hostName
	};
}

export function RecordTable({ records, rowType = "records", lazyParams, setLazyParams, rowsPerPage, loading}) {
	const tableTypeSpecifics = {
		"records": [recordsColumns, createRecordsRow],
		"iocDetails": [iocDetailsColumns, createIocDetailsRow]
	}

	const [columns, createRow] = tableTypeSpecifics[rowType];

	return( 
    <CustomTable 
      columns={columns} 
      rows={records.recordList.map(record => createRow(record))}
      // Total count must be practically infinity for now (till total count can be retrieved from API)
      totalCount={records.listSize < records.limit ? records.listSize + records.limit * records.pageNumber : 1000000}
      lazyParams={lazyParams} 
      setLazyParams={setLazyParams} 
      rowsPerPage={rowsPerPage} 
      loading={loading}
      paginatorTemplate="FirstPageLink PrevPageLink NextPageLink RowsPerPageDropdown"
    />
  )
}