import { matchPath } from "react-router-dom";

function getParameters(req, pattern) {
  const match = matchPath(
    { path: "/api/v1" + pattern, },
      new URL(req.url).pathname,
    );
  return match?.params;
}

function spec(req) {
  const data = require("./fixtures/ccce-api.json");
  return {
    body: data
  }
}

function login(req) {
  const token = "DEADBEEF";
  return {
    body: { token },
    headers: {
      "Set-Cookie": `ce-deploy-auth=${token}`
    }
  }
}

function logout(req) {
  return {
    headers: {
      "Set-Cookie": "ccce-auth=; Max-Age=0"
    }
  }
}

function isLoggedIn(req) {
  if (req.cookies) {
    return Boolean(req.cookies["ce-deploy-auth"]);
  }
  else {
    return (req.headers?.cookie ?? "").includes("ce-deploy-auth=");
  }
}

function auth(routeHandler) {
  return function (req) {
    if (isLoggedIn(req)) {
      return routeHandler(req);
    }
    else {
      return { status: 401 }
    }
  }
}

function getUserRoles(req) {
  const body = ["DeploymentToolAdmin", "DeploymentToolIntegrator"];
  return { body }
}

function infoFromUserName(req) {
  const body = [{
    "fullName": "John Wayne",
    "loginName": "johnwayne",
    "avatar": "https://gitlab.esss.lu.se/uploads/-/system/user/avatar/92/avatar.png",
    "email": null
  }];
  return { body }
}

function renew(req) {
  const token = "FADEDEAD";
  return {
    body: { token },
    headers: {
      "Set-Cookie": `ce-deploy-auth=${token}`
    }
  }
}

function listIOCs(req) {
  const body = require("./fixtures/PagedIOCResponse.json");
  return { body }
}

function getIOC(req) {
  const params = getParameters(req, "/iocs/:id")
  const data = require("./fixtures/IOCDetails.json")
  const body = data.find(x => x.id === parseInt(params.id));
  console.log("getIOC", data, params, body);
  const status = body ? 200 : 404
  return { body, status }
}

function getDeployment(req) {
  console.log(req);
  const params = getParameters(req, "/deployments/:id")
  console.log(params);
  const data = require("./fixtures/DeploymentInfoDetails.json");
  const body = data.find(x => x.id === parseInt(params.id));
  const status = body ? 200 : 404
  return { body, status }
}

function getDeploymentJob(req) {
  const params = getParameters(req, "/deployments/jobs/:id");
  const data = require("./fixtures/AwxJobDetails.json");
  const body = data.find(x => x.id === parseInt(params.id));
  const status = body ? 200 : 404
  return { body, status }
}

function getDeploymentJobLog(req) {
  const params = getParameters(req, "/deployments/jobs/:id/log");
  const jobDetailsData = require("./fixtures/AwxJobDetails.json");
  const index = jobDetailsData.findIndex(x => x.id === parseInt(params.id))
  const logData = require("./fixtures/AwxJobLog.json");
  const body = logData[index];
  const status = body ? 200 : 404
  return { body, status }
}

function getCommandList(req) {
  const body = require("./fixtures/PagedCommandResponse.json");
  return { body }
}

function getCSEntryHostWithStatus(req) {
  const params = getParameters(req, "/hosts/:id/with_status")
  const data = require("./fixtures/CSEntryHostWithStatus.json");
  const body = data.find(x => x.csEntryHost.id === parseInt(params.id));
  const status = body ? 200 : 404
  return { body, status }
}

function getProcservLogs(req) {
  const body = require("./fixtures/LokiResponse.json");
  return { body }
}

function getStatistics(req) {
  const body = require("./fixtures/GeneralStatisticsResponse.json");
  return { body };
}

function currentlyActiveIocs(req) {
  const body = require("./fixtures/ActiveIocStatisticsResponse.json");
  return { body };
}

function iocDeploymentHistory(req) {
  const body = require("./fixtures/DeployedIOCsHistory.json");
  return { body };
}

function activeIocHistory(req) {
  const body = require("./fixtures/ActiveIOCsForHistoryResponse.json");
  return { body };
}

// just to organize
const mockAPI = {
  spec: spec,
  authentication: {
    login,
    logout,
    renew,
    getUserRoles,
  },
  iocs: {
    listIOCs,
    getIOC,
  },
  deployments: {
    getDeployment,
    getDeploymentJob,
    getDeploymentJobLog,
    getCommandList,
  },
  hosts: {
    getCSEntryHostWithStatus,
  },
  git_helper: {
    infoFromUserName,
  },
  monitoring: {
    getProcservLogs,
  },
  statistics: {
    getStatistics,
    currentlyActiveIocs,
    iocDeploymentHistory,
    activeIocHistory,
  }
}

// Enough info to create handlers in cypress or MSW
const makeHandler = (method, matcher, requestHandler, wrapper) => ({
  method,
  matcher,
  requestHandler: wrapper ? wrapper(requestHandler) : requestHandler,
  name: requestHandler.name // use caution when changing api function names
});

const queryPattern = "(\\?.*)?$";
const qRegExp = (pattern) => RegExp(pattern + queryPattern)

// Handlers for our whole API
export const apiHandlers = [
  // api spec
  makeHandler("GET", qRegExp(".*/api/spec"), mockAPI.spec),

  // authentication
  makeHandler("POST", qRegExp(".*/authentication/login"), mockAPI.authentication.login),
  makeHandler("POST", qRegExp(".*/authentication/logout"), mockAPI.authentication.logout, auth),
  makeHandler("POST", qRegExp(".*/renew"), mockAPI.authentication.renew, auth),
  makeHandler("GET", qRegExp(".*/authentication/roles"), mockAPI.authentication.getUserRoles, auth),

  // iocs
  makeHandler("GET", qRegExp(".*/iocs"), mockAPI.iocs.listIOCs),
  makeHandler("GET", qRegExp(".*/iocs/[0-9]+"), mockAPI.iocs.getIOC),
  // git
  makeHandler("GET", qRegExp(".*/git_helper/user_info"), mockAPI.git_helper.infoFromUserName, auth),

  // deployments
  makeHandler("GET", qRegExp(".*/deployments/[0-9]+"), mockAPI.deployments.getDeployment),
  makeHandler("GET", qRegExp(".*/deployments/jobs/[0-9]+"), mockAPI.deployments.getDeploymentJob),
  makeHandler("GET", qRegExp(".*/deployments/jobs/[0-9]+/log"), mockAPI.deployments.getDeploymentJobLog, auth),

  // commands
  makeHandler("GET", qRegExp(".*/deployments/commands"), mockAPI.deployments.getCommandList),

  // hosts
  makeHandler("GET", qRegExp(".*/hosts/[0-9]+/with_status"), mockAPI.hosts.getCSEntryHostWithStatus),

  // monitoring
  makeHandler("GET", qRegExp(".*/monitoring/procserv/host/.+"), mockAPI.monitoring.getProcservLogs, auth),

  // statistics
  makeHandler("GET", qRegExp(".*/statistics/general"), mockAPI.statistics.getStatistics),
  makeHandler("GET", qRegExp(".*/statistics/general/active_ioc_statistics"), mockAPI.statistics.currentlyActiveIocs),
  makeHandler("GET", qRegExp(".*/statistics/general/deployed_ioc_history"), mockAPI.statistics.iocDeploymentHistory),
  makeHandler("GET", qRegExp(".*/statistics/general/active_ioc_history"), mockAPI.statistics.activeIocHistory),
]