import { Grid, Paper, Tab, Tabs, Typography, IconButton } from "@material-ui/core";
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import React, { useCallback, useEffect, useState } from "react";
import { useOngoingCommand, useCommandList } from "../../api/SwaggerApi";
import { IOCLiveStatus } from "../../components/IOC/IOCLiveStatus";
import { IOCManage } from "../../components/IOC/IOCManage";
import { useNavigate } from "react-router-dom";
import IOCAdmin from "../../components/IOC/IOCAdmin";
import AccessControl from "../../components/auth/AccessControl";
import { initRequestParams } from "../../components/common/Helper";
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { useSafePolling } from "../../hooks/Polling";

const IOC_POLL_INTERVAL = 10000;
export function IOCDetailsView({ ioc, getIOC, loading }) {
  
  const [selectedTab, setSelectedTab] = useState("Status");
  const [firstTime, setFirstTime] = useState(true);
  const [buttonDisabled, setButtonDisabled] = useState(false);
  const navigate = useNavigate();
  const [commands, getCommands, /*reset*/, commandsLoading] = useCommandList();
  const [ongoingCommand, getOngoingCommand, /*reset*/, ongoingCommandLoading] = useOngoingCommand(ioc.id);

  const [commandLazyParams, setCommandLazyParams] = useState({
    rows: 5,
    page: 0
  });

  const [commandColumnSort, setCommandColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  useSafePolling(getIOC, loading, IOC_POLL_INTERVAL);
  useSafePolling(getOngoingCommand, ongoingCommandLoading, IOC_POLL_INTERVAL);

  useEffect(() => {
    setButtonDisabled(Boolean(ioc?.operationInProgress));
  }, [ioc?.operationInProgress]);

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  useEffect(() => {
    if (firstTime && ioc && ioc.activeDeployment) {
      setSelectedTab("Status");
      setFirstTime(false);
    }
  }, [ioc, firstTime]);

  useEffect(() => {
    if(ioc.activeDeployment) {
      let requestParams = initRequestParams(commandLazyParams, null, commandColumnSort);
      requestParams.ioc_id = ioc.id;
      //requestParams.deployment_id = ioc.activeDeployment.id;
      getCommands(requestParams);
    }
  }, [getCommands, commandLazyParams, commandColumnSort, ioc])

  const handleClick = () => {
    navigate(-1);
  };

  const resetTab = useCallback( () => {
    if (ioc?.activeDeployment) {
      setSelectedTab("Status");
    } else {
      setSelectedTab("Manage deployment");
    }
  }, [ioc?.activeDeployment])

  const setButtonDisabledAndUpdate = useCallback((isDisabled) => {
    setButtonDisabled(isDisabled);
    getIOC();
  }, [getIOC])

  const { setTitle } = useGlobalAppBar("IOC Details");

  useEffect(() => {
    ioc && setTitle("IOC Details: " + ioc.namingName);
  }, [ioc, setTitle]);

  const statusTab = <Tab key="Status" label={<Typography variant="h5">Status</Typography>} value="Status" />
  const manageDeploymentTab = <Tab key="Manage deployment" label={<Typography variant="h5">Management</Typography>} value="Manage deployment" />
  const iocAdminTab = <Tab key="IOC Admin" label={<Typography variant="h5">Admin</Typography>} value="IOC Admin" />

  const CustomTabs = ({ children }) => {
    return (
      <Tabs
        value={selectedTab}
        onChange={handleTabChange}
        indicatorColor="primary"
        textColor="primary"
      >
        {children}
      </Tabs>
    );
  }

  return (
    <Paper>
      <Grid container spacing={1}>
        <Grid item xs={1}>
          <IconButton color="inherit" onClick={handleClick}>
            <ArrowBackIcon />
          </IconButton>
        </Grid>
        <Grid item xs={11}>
          <Grid container justify="center">
            {ioc && 
              <CustomTabs>
                {statusTab}
                <AccessControl
                  allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
                  renderNoAccess={() =><></>} >
                  <CustomTabs>
                    {manageDeploymentTab}
                  </CustomTabs>
                </AccessControl>
                <AccessControl
                  allowedRoles={["DeploymentToolAdmin", "DeploymentToolManager"]}
                  allowedUsersWithRoles={[{ user: ioc.owner, role: "DeploymentToolIntegrator" }]}
                  renderNoAccess={() =><></>} >
                  <CustomTabs>
                    {iocAdminTab}
                  </CustomTabs>
                </AccessControl>
              </CustomTabs>
            }
          </Grid>
        </Grid>
        <Grid item xs={12} style={{ paddingBottom: 0 }}>
          {selectedTab === "Status" && 
            <IOCLiveStatus 
              ioc={ioc} 
            />}
          {selectedTab === "Manage deployment" && 
            <IOCManage 
              ioc={ioc} 
              getIOC={getIOC} 
              buttonDisabled={buttonDisabled} 
              currentCommand={ongoingCommand}
              commands={commands}
              commandsLoading={commandsLoading}
              getCommands={getCommands}
              setButtonDisabled={setButtonDisabledAndUpdate}
              commandColumnSort={commandColumnSort}
              setCommandColumnSort={setCommandColumnSort}
              commandLazyParams={commandLazyParams}
              setCommandLazyParams={setCommandLazyParams}
            />}
          {selectedTab === "IOC Admin" && <IOCAdmin ioc={ioc} getIOC={getIOC} resetTab={resetTab} buttonDisabled={buttonDisabled} />}
        </Grid>
      </Grid>
    </Paper>
  );
}