import { Container, Grid, Paper, FormControlLabel, Switch, Typography, Tabs, Tab } from "@material-ui/core";
import { RootContainer } from "../../components/common/Container/RootContainer";
import React, { useState, useEffect, useContext, useCallback } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { IOCAsyncList } from "../../components/IOC/IOCAsyncList";
import { useIOCSearch, userContext } from "../../api/SwaggerApi";
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams } from "../../components/common/Helper";
import { SearchBar } from "../../components/common/SearchBar/SearchBar";
import AccessControl from '../../components/auth/AccessControl';
import useUrlState from '@ahooksjs/use-url-state';
import { serialize, deserialize } from "../../components/common/URLState/URLState";

const useStyles = makeStyles((theme) => ({
    root: {
        marginBottom: theme.spacing(2),
    },
}));

export function IOCListView() {
    const [iocs, getIocs, /*reset*/, loading] = useIOCSearch();
    const [iocList, setIocList] = useState([]);

    const [state, setState] = useUrlState({ tab: '0', own: 'false', rows: '20', page: '0', query: '' });

    const [deploymentStatus, setDeploymentStatus] = useState("ALL");
    const { user } = useContext(userContext);
    const classes = useStyles();

    const handleTabChange = useCallback((tab) => {
        setState((s) => (serialize(s.tab) === serialize(tab) ? {tab: serialize(tab)} : {tab: serialize(tab), page: '0'}))

        if (tab === 0) {
            setDeploymentStatus("ALL");
        }
        else if (tab === 1) {
            setDeploymentStatus("DEPLOYED");
        }
        else if (tab === 2) {
            setDeploymentStatus("NOT_DEPLOYED");
        }
    }, [setState]);

    useEffect(() => {
        state.tab && handleTabChange(deserialize(state.tab))
    }, [state, handleTabChange])

    const lazyParams = useCallback(() => {
        return({
            rows: deserialize(state.rows),
            page: deserialize(state.page)
        })
    }, [state])

    const setLazyParams = useCallback((params) => {
        setState({rows: serialize(params.rows), page: serialize(params.page)})
    }, [setState])

    const handleChangeOwn = (event) => {
        const own = event.target.checked
        setState({own: serialize(own), page: '0'})
    };

    const rowsPerPage = [20, 50];

    useEffect(() => {
        setIocList(iocs.iocList);
    }, [iocs, setIocList])

    useEffect(() => {
        let requestParams = initRequestParams(lazyParams(), deserialize(state.query));

        if (deserialize(state.own)) {
            requestParams.owner = user?.loginName;
        }

        requestParams.deployment_status = deploymentStatus;

        getIocs(requestParams);
    }, [getIocs, lazyParams, user, state, deploymentStatus])

    const title = "IOCs";
    useGlobalAppBar(title);

    const setSearch = useCallback((query) => {
        setState({query: serialize(query)})
    }, [setState]);

    let content = (
        <SearchBar search={setSearch} query={deserialize(state.query)} loading={loading} placeholder="Search in IOC name or user">
            <IOCAsyncList iocs={iocList} setIocs={setIocList} loading={loading} rowType="explore"
                lazyParams={lazyParams()} setLazyParams={setLazyParams} totalCount={iocs.totalCount}
                rowsPerPage={rowsPerPage} />
        </SearchBar>
    );

    return (
        <RootContainer>
            <Paper className={classes.root}>
                <Grid container spacing={1}>
                    <Grid container spacing={1} component={Container} justify="space-between" alignItems="center" style={{ display: "flex" }} >
                        <Grid item>
                            <Tabs
                                value={parseInt(state.tab)}
                                onChange={(event, tab) => handleTabChange(tab)}
                                indicatorColor="primary"
                                textColor="primary">
                                <Tab label={<Typography variant="h5">All</Typography>} />
                                <Tab label={<Typography variant="h5">Only Deployed</Typography>} />
                                <Tab label={<Typography variant="h5">Only Not Deployed</Typography>} />
                            </Tabs>
                        </Grid>
                        <Grid item>
                            <AccessControl allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
                                renderNoAccess={() => <></>} >
                                <FormControlLabel className={classes.formControl}
                                    control={<Switch checked={deserialize(state.own)} onChange={handleChangeOwn} />}
                                    label={<Typography variant="h5">Only my IOCs</Typography>}
                                />
                            </AccessControl>
                        </Grid>
                    </Grid>
                    <Grid item xs={12} md={12}>
                        {content}
                    </Grid>
                </Grid>
            </Paper>
        </RootContainer>
    );
}

