import React from "react";
import {
  Paper,
  Link,
  Typography,
  makeStyles
} from "@material-ui/core";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import './helpfile.css';
import { RootContainer } from "../../components/common/Container/RootContainer";

const useStyles = makeStyles((theme) => ({
  paper: {
    padding: theme.spacing(4),
  },
}));

export function HelpView() {
  const classes = useStyles();
  const title = "Help";
  useGlobalAppBar(title);

  return (
    <RootContainer>
      <h2>Help</h2>
      <Paper className={classes.paper}>
        <Typography variant="body1">
          <p>Before you can deploy an IOC, you need to:
            <ul>
              <li>have your IOC registered in <Link href="https://ccdb.esss.lu.se/" target="_blank" rel="noreferrer">CCDB</Link> (go <Link href="https://confluence.esss.lu.se/x/k41nFg" target="_blank" rel="noreferrer">here</Link> for help)</li>
              <li>have an IOC host registered in <Link href="https://csentry.esss.lu.se/" target="_blank" rel="noreferrer">CSEntry</Link></li>
              <li>have your IOC in a ESS GitLab repository in the &quot;<Link href="https://gitlab.esss.lu.se/iocs" target="_blank" rel="noreferrer">iocs&#47;</Link>&quot; group (you can use <Link href="https://gitlab.esss.lu.se/ics-cookiecutter/cookiecutter-e3-ioc" target="_blank" rel="noreferrer">cookiecutter</Link> to create the repository, or you can create it by hand - you can find an example IOC repository <Link href="https://gitlab.esss.lu.se/ccce/dev/e3-ioc-ccce-example" target="_blank" rel="noreferrer">here</Link>)</li>
            </ul>
            Deployments shall be done on blank (formatted) machines set up with CSEntry - some configuration is done during OS installation. Deployments made on old hosts, or hosts which make use mixed deployment methods (e.g. with both manually and CE-deployed IOCs) are not supported by the CE team.

            Note that we currently only support deployments on CentOS 7.</p>

          <hr />

          <p>If you need support, please visit the <Link href="https://ess-eric.slack.com/archives/C01V3R31EP2" target="_blank" rel="noreferrer">#ccce-ioc-deployment-beta</Link> channel on ESS&lsquo; Slack.</p>

          <p>We also have a <Link href="https://confluence.esss.lu.se/x/3fPIFQ" target="_blank" rel="noreferrer">bug and known issues page</Link>, as well as a number of <Link href="https://confluence.esss.lu.se/x/CVGQFg" target="_blank" rel="noreferrer">help articles</Link>.</p>
        </Typography>
      </Paper>
      <h2>FAQ</h2>
      <Paper className={classes.paper}>
        <Typography variant="body1">
          <h4>How do I change which host my IOC is deployed on?</h4>
          In order to change hosts for an IOC, you must
          <ul>
            <li>Undeploy the IOC from its current host</li>
            <li>Deploy it to the new host.</li>
          </ul>

          <h4>Why do I first need to register the IOC, and then deploy it separately?</h4>
          This deployment tool is only a part of the IOC management toolchain. When the full toolchain is complete an IOC will be generated from modeling and configuration data and will not need to be registered. As those tools do not yet exist, you must first register your IOC as if it were coming from an earlier part of a complete toolchain.

          Deployment would at that time be a separate stage that takes an abstract IOC and then places it on a configured and prepared host.

          <h4>Why can I not see my IOC/host/repository in the dropdown list?</h4>
          The deployment tool will only show you valid IOCs, hosts, and repositories.
          <ul>
            <li>In order to to register an IOC, it must be registered in CCDB.</li>
            <li>In order to deploy to a host, it needs to be configured as an IOC host in CSEntry.</li>
            <li>In order to find an IOC repository, it needs to exist in the &quot;<Link href="https://gitlab.esss.lu.se/iocs" target="_blank" rel="noreferrer">iocs&#47;</Link>&quot; GitLab group.</li>
          </ul>

          <h4>What does the deployment system do? Is there something I need to be aware of?</h4>
          The deployment system will set up a host machine to run only IOCs defined in this tool, and will configure all necessary services to do so. This means that it might interfere with other (already running) processes on the machine, which is part of why it is a requirement to start from blank (formatted) machines; another part of this requirement comes from some setup being done at the OS-installation stage.

          <h4>How do I migrate IOCs that have been deployed with another deployment system (e.g. CCCE alpha or LDS)?</h4>
          In order to migrate an IOC that was deployed with a separate system, manually, or otherwise, you must ensure that all of the above conditions are satisfied (that is, your IOC is registered, the repository is in GitLab, and the host is registered). You should then
          <ul>
            <li>Undeploy the IOC from whatever system you used to deploy it</li>
            <li>Request from CSI that the host be freshly formatted</li>
          </ul>
          Please note that the second point is important as there is necessary configuration done during the initial host configuration stage.

          <h4>What does the yellow and red backgrounds on an IOC/host mean?</h4>
          A red or a yellow background means that an IOC or host has various issues that need to be addressed. Details on the specific issues can be found for the IOC or host&rsquo;s own details page.

          <h4>How do I transfer ownership of an IOC?</h4>
          Please contact the CCCE team for help.

          <h4>I accidentally connected to the wrong CCDB IOC/the wrong git repository - what do I do?</h4>
          Please contact the CCCE team for help.
        </Typography>
      </Paper>
    </RootContainer>
  )
}