import React, { useState, useEffect } from "react";
import {
  Paper, Grid
} from '@material-ui/core';
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { RootContainer } from "../../components/common/Container/RootContainer";
import { useChannelSearch } from "../../api/SwaggerApi";
import { initRequestParams } from "../../components/common/Helper";
import { RecordTable } from "../../components/records/RecordTable";
import { SearchBar } from "../../components/common/SearchBar/SearchBar";

export function RecordListView() {
  useGlobalAppBar("Records");

  const [records, getRecords, /*reset*/, loading] = useChannelSearch();
  const [query, setQuery] = useState("");

  const [lazyParams, setLazyParams] = useState({
    rows: 20,
    page: 0
  });

  const rowsPerPage = [20, 50];

  useEffect(() => {
      let requestParams = initRequestParams(lazyParams);
      if (query && query.length > 0) {
        requestParams = {
          ...requestParams,
          record_name: "*" + query + "*"
        }
      }

      getRecords(requestParams);
  }, [getRecords, lazyParams, query])

  const content = (
    <>
      <SearchBar search={setQuery} loading={loading} placeholder="Search in Record">
        <RecordTable records={records} loading={loading}
            lazyParams={lazyParams} setLazyParams={setLazyParams}
            rowsPerPage={rowsPerPage} />
      </SearchBar>
    </>
);

  return (
    <RootContainer>
      <Paper>
        <Grid container spacing={1}>
          <Grid item xs={12} md={12}>
            {content}
          </Grid>
        </Grid>
      </Paper>
    </RootContainer>
  );
}
